@@ -1,7 +1,7 @@
 .onLoad <- function(lib, pkg)
 {
     ## This assumes  "gv"  in your path --- ideally this would be configured!
-    if(.Platform $ OS.type == "unix") {
+    if(!is.character(getOption("eps_view")) && .Platform $ OS.type == "unix") {
 	SYS <- function(cmd) system(cmd, intern=TRUE, ignore.stderr=TRUE)
         doesRespond <- function(cmd) length(SYS(cmd)) > 0
 	if(doesRespond("gv -h")) { ## 'gv'
@@ -28,7 +28,6 @@
 	}
 	options("eps_view" = cmd)
     }
-
 }
 
 ## was	.First.lib <- function(lib, pkg) { .. }
